pub enum Csr {
Automatic(PKey<Private>),
Custom(X509Req),
}Expand description
A certificate signing request.
Variants
Automatic(PKey<Private>)
Automatic signing takes just a private key. The other details of the CSR (identifiers, common name, etc), will be automatically retrieved from the order this is used with.
Custom(X509Req)
A custom CSR will not be modified, and will be passed to the ACME server as is.