pub struct Account {
pub id: String,
pub status: AccountStatus,
pub contact: Option<Vec<String>>,
pub terms_of_service_agreed: Option<bool>,
/* private fields */
}Expand description
An ACME account. This is used to identify a subscriber to an ACME server.
This resource should be created through an AccountBuilder.
Fields
id: StringThe account ID of this account.
status: AccountStatusThe status of this account.
contact: Option<Vec<String>>An array of URLs that the server can use to contact the client for issues related to this account.
terms_of_service_agreed: Option<bool>Including this field in a newAccount request, with a value of true, indicates the client’s agreement with the terms of service.
Implementations